pub struct RemoteAllocator { /* private fields */ }Expand description
This is a stripped down entity allocator that operates on fewer assumptions than EntityAllocator.
As a result, using this will be slower than the main allocator but this offers additional freedoms.
In particular, this type is fully owned, allowing you to allocate entities for a world without locking or holding reference to the world.
This is especially useful in async contexts.
Implementations
Sourceimpl RemoteAllocator
impl RemoteAllocator
Sourcepub fn alloc(&self) -> Entity
pub fn alloc(&self) -> Entity
Allocates an entity remotely.
This comes with a major downside:
Because this does not hold reference to the world, the world may be cleared or destroyed before you get a chance to use the result.
If that happens, these entities will be garbage!
They will not be unique in the world anymore and you should not spawn them!
Before using the returned values in the world, first check that it is ok with EntityAllocator::has_remote_allocator.
Sourcepub fn is_closed(&self) -> bool
pub fn is_closed(&self) -> bool
Returns whether or not this RemoteAllocator is still connected to its source EntityAllocator.
Note that this could close immediately after the function returns false, so be careful.
The best way to ensure that does not happen is to only trust the returned value while holding a reference to the world
and to ensure it is the right world through EntityAllocator::has_remote_allocator.
This is generally best used as a diagnostic.
EntityAllocator::has_remote_allocator is a better check for correctness.